@@ -28,7 +28,7 @@ require utf8;
 } unless defined &utf8::is_utf8;
 
 $DBI::PurePerl = $ENV{DBI_PUREPERL} || 1;
-$DBI::PurePerl::VERSION = sprintf("2.%06d", q$Revision: 13658 $ =~ /(\d+)/o);
+$DBI::PurePerl::VERSION = "2.014286";
 
 $DBI::neat_maxlen ||= 400;
 
@@ -120,7 +120,7 @@ use constant IMA_NO_TAINT_IN   	=> 0x0010; #/* don't check for tainted args*/
 use constant IMA_NO_TAINT_OUT   => 0x0020; #/* don't taint results	*/
 use constant IMA_COPY_UP_STMT   => 0x0040; #/* copy sth Statement to dbh */
 use constant IMA_END_WORK	=> 0x0080; #/* set on commit & rollback	*/
-use constant IMA_STUB		=> 0x0100; #/* donothing eg $dbh->connected */
+use constant IMA_STUB		=> 0x0100; #/* do nothing eg $dbh->connected */
 use constant IMA_CLEAR_STMT     => 0x0200; #/* clear Statement before call  */
 use constant IMA_UNRELATED_TO_STMT=> 0x0400; #/* profile as empty Statement   */
 use constant IMA_NOT_FOUND_OKAY	=> 0x0800; #/* not error if not found */
@@ -143,6 +143,7 @@ my %is_flag_attribute = map {$_ =>1 } qw(
 	TaintIn
 	TaintOut
 	InactiveDestroy
+	AutoInactiveDestroy
 	LongTruncOk
 	MultiThread
 	PrintError
@@ -224,7 +225,13 @@ sub  _install_method {
     return if $method_name eq 'can';
 
     push @pre_call_frag, q{
-	return if $h_inner; # ignore DESTROY for outer handle
+        # ignore DESTROY for outer handle (DESTROY for inner likely to follow soon)
+	return if $h_inner;
+        # handle AutoInactiveDestroy and InactiveDestroy
+        $h->{InactiveDestroy} = 1
+            if $h->{AutoInactiveDestroy} and $$ != $h->{dbi_pp_pid};
+        $h->{Active} = 0
+            if $h->{InactiveDestroy};
 	# copy err/errstr/state up to driver so $DBI::err etc still work
 	if ($h->{err} and my $drh = $h->{Driver}) {
 	    $drh->{$_} = $h->{$_} for ('err','errstr','state');
@@ -527,6 +534,7 @@ sub _setup_handle {
 	$h_inner->{Type}                ||= 'dr';
     }
     $h_inner->{"dbi_pp_call_depth"} = 0;
+    $h_inner->{"dbi_pp_pid"} = $$;
     $h_inner->{ErrCount} = 0;
     $h_inner->{Active} = 1;
 }
@@ -701,7 +709,7 @@ sub sql_type_cast {
         else {
             return -2;
         }
-    } or warn $@;
+    } or $^W && warn $@; # XXX warnings::warnif("numeric", $@) ?
 
     return $evalret if defined($evalret) && ($evalret == -2);
     $cast_ok = 0 unless $evalret;
@@ -749,7 +757,7 @@ sub _get_sorted_hash_keys {
             for keys %$hash_ref;
         $num_sort = $sort_guess;
     }
-    
+
     my @keys = keys %$hash_ref;
     no warnings 'numeric';
     my @sorted = ($num_sort)
@@ -943,7 +951,7 @@ sub take_imp_data {
     my $dbh = shift;
     # A reasonable default implementation based on the one in DBI.xs.
     # Typically a pure-perl driver would have their own take_imp_data method
-    # that would delete all but the essential items in the hash before einding with:
+    # that would delete all but the essential items in the hash before ending with:
     #      return $dbh->SUPER::take_imp_data();
     # Of course it's useless if the driver doesn't also implement support for
     # the dbi_imp_data attribute to the connect() method.
@@ -1113,7 +1121,7 @@ bug reports to Jeff Zucker at <jeff@vpservices.com> with a cc to
 =head1 USAGE
 
 The usage is the same as for standard DBI with the exception
-that you need to set the enviornment variable DBI_PUREPERL if
+that you need to set the environment variable DBI_PUREPERL if
 you want to use the PurePerl version.
 
  DBI_PUREPERL == 0 (the default) Always use compiled DBI, die
@@ -1124,7 +1132,7 @@ you want to use the PurePerl version.
 
  DBI_PUREPERL == 2 Always use PurePerl
 
-You may set the enviornment variable in your shell (e.g. with
+You may set the environment variable in your shell (e.g. with
 set or setenv or export, etc) or else set it in your script like
 this:
 
@@ -1168,6 +1176,7 @@ functionality:
 
   ActiveKids
   InactiveDestroy
+  AutoInactiveDestroy
   Kids
   Taint
   TaintIn
@@ -1178,7 +1187,7 @@ functionality:
 =head2 Tracing
 
 Trace functionality is more limited and the code to handle tracing is
-only embeded into DBI:PurePerl if the DBI_TRACE environment variable
+only embedded into DBI:PurePerl if the DBI_TRACE environment variable
 is defined.  To enable total tracing you can set the DBI_TRACE
 environment variable as usual.  But to enable individual handle
 tracing using the trace() method you also need to set the DBI_TRACE
